@@ -64,12 +64,16 @@ class hcfg():
                     return
                 name = object[0].strip(" ")
                 value = hcfg.assignValue(object[1])
-                if(value.startswith("{")):
-                    value = value.replace("'",'"')
-                    dict = json.loads(value)
-                    buffer[name] = dict
-                else:
-                    buffer[name] = value
+                try:
+                    if(value.startswith("{")):
+                        value = value.replace("'",'"')
+                        dict = json.loads(value)
+                        buffer[name] = dict
+                    else:
+                        buffer[name] = value
+                except:
+                    None
+                buffer[name] = value
             return buffer
 
     @staticmethod
